#' @keywords internal
#' @aliases palette-package
'_PACKAGE'

## usethis namespace: start
#' @importFrom pillar pillar_shaft
## usethis namespace: end
NULL

#' Internal vctrs methods
#'
#' @import vctrs
#' @keywords internal
#' @name palette-vctrs
NULL
